pitchtools.PitchClassVector
===========================

.. abjad-lineage:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector

.. autoclass:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.clear
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.copy
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.custom_identifier
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.elements
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.from_selection
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.item_class
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.items
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.iteritems
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.iterkeys
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.itervalues
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.keys
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.most_common
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.subtract
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.update
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.values
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewitems
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewkeys
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewvalues
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__add__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__and__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__contains__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__delitem__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__eq__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__format__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__getitem__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__iter__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__len__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__makenew__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__missing__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__ne__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__or__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__repr__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__setitem__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__str__
      ~abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__sub__

Bases
-----

- :py:class:`pitchtools.Vector <abjad.tools.pitchtools.Vector.Vector>`

- :py:class:`datastructuretools.TypedCounter <abjad.tools.datastructuretools.TypedCounter.TypedCounter>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.clear
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.elements
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.items
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.iteritems
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.iterkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.itervalues
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.keys
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.most_common
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.subtract
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.update
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.values
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewitems
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.viewvalues
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__missing__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassVector.PitchClassVector.__sub__
   :noindex:
